AcceptChannelCommand class

Accept an incoming channel request

Constructors

AcceptChannelCommand({required String channelId, required String walletId, required String clientPeerId, required String clientPubKey, required String clientAddress, required int fundingAmountSats, required int lockTimeUnix})

Properties

channelId String
final
clientAddress String
final
clientPeerId String
final
clientPubKey String
final
correlationId String
The correlation ID of the message.
no setter
fundingAmountSats int
final
hashCode int
The hash code for this object.
no setterinherited
lockTimeUnix int
final
metadata Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited