failure property

  1. @override
String? get failure
override

Why the request failed, or null when it succeeded. WalletCoordinator.ask throws a CoordinatorFailure carrying this reply when it is not null.

Implementation

@override
String? get failure => valid || awaitingHeader ? null : error ?? 'The payment did not validate';