pendingBalance property
See BalanceResponse.pendingBalance: the wallet's money the network is not known to hold, or whose proof a reorganization took away. Not part of totalBalance.
Implementation
final BigInt pendingBalance;
See BalanceResponse.pendingBalance: the wallet's money the network is not known to hold, or whose proof a reorganization took away. Not part of totalBalance.
final BigInt pendingBalance;