BroadcastFailureEvent class

A broadcast to ARC failed that no request is waiting on (a durable retry, or a broadcast another actor started).

Inheritance

Constructors

BroadcastFailureEvent({String? walletId, required String txid, required String error, required bool willRetry})

Properties

error → String
final
eventTimestamp → DateTime
When the event was made.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txid → String
final
walletId → String?
Optional wallet ID for filtering events by wallet
final
willRetry → bool
ARCActor queued the broadcast for a durable retry. False for a definitive refusal, and on a backend without the retry queue.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited