willRetry property
ARCActor queued the broadcast for a durable retry. False for a definitive refusal, and on a backend without the retry queue.
Implementation
final bool willRetry;
ARCActor queued the broadcast for a durable retry. False for a definitive refusal, and on a backend without the retry queue.
final bool willRetry;