fundingTxId property
The funding transaction that was re-broadcast; null when the retry was refused before one was read from the channel's state.
Implementation
final String? fundingTxId;
The funding transaction that was re-broadcast; null when the retry was refused before one was read from the channel's state.
final String? fundingTxId;