ChannelOpenedEvent class

Channel opened successfully

Inheritance

Constructors

ChannelOpenedEvent({required String walletId, required String channelId, String? fundingTxId, required int fundingAmountSats, String? requestId})

Properties

channelId → String
final
eventTimestamp → DateTime
When the event was made.
finalinherited
failure → String?
Never: a failure to answer arrives as an ErrorEvent.
no setteroverride
fundingAmountSats → int
final
fundingTxId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → String?
The CoordinatorRequest.requestId of the request this answers; null when no request caused it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited