ChannelP2PMessageToSendEvent class

Outgoing P2P message that the app must transmit to the peer

Inheritance

Constructors

ChannelP2PMessageToSendEvent({required String toPeerId, required String messageType, required Map<String, dynamic> payload})

Properties

eventTimestamp DateTime
Timestamp of the event
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
messageType String
final
payload Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toPeerId String
final
walletId String?
Optional wallet ID for filtering events by wallet
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited