ChannelPayCommand class

Make a payment over an open channel

Constructors

ChannelPayCommand({required String channelId, required String walletId, required int amountSats, String? purpose, String? invoiceId})

Properties

amountSats int
final
channelId String
final
correlationId String
The correlation ID of the message.
no setter
hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
final
metadata Map<String, dynamic>
The metadata of the message.
no setter
purpose String?
final
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited