refundTxId property
The refund that was broadcast and journaled; null when the claim failed before one was read from the channel's state.
Implementation
final String? refundTxId;
The refund that was broadcast and journaled; null when the claim failed before one was read from the channel's state.
final String? refundTxId;