CoordinatorEvent class abstract
Base class for all coordinator events emitted on the event stream.
Third-party apps subscribe to Stream<CoordinatorEvent> to receive
async results from the coordinator, or wait for one request's answer
with WalletCoordinator.ask.
- Implementers
- AncestorProofRequestReceivedEvent
- AncestorProofResponseEvent
- BalanceUpdatedEvent
- BroadcastFailureEvent
- ChannelPaymentPendingEvent
- ChannelRequestReceivedEvent
- CoordinatorReply
- ErrorEvent
- HeaderSyncStatusEvent
- ImportProgressEvent
- ImportTransactionConfirmedEvent
- ImportUTXOConfirmedEvent
- InvoicePaidEvent
- P2PMessageToSendEvent
- SPVValidationResultEvent
- TransactionConfirmationRevertedEvent
- TransactionConfirmedEvent
- UnfinishedChannelsFoundEvent
- UTXOSplitStartedEvent
- WalletStatusEvent
Constructors
Properties
- eventTimestamp → DateTime
-
When the event was made.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited