failure property

String? get failure

Why the request failed, or null when it succeeded. WalletCoordinator.ask throws a CoordinatorFailure carrying this reply when it is not null.

Implementation

String? get failure;