DeferredPaymentCancelledEvent class

Inheritance

Constructors

DeferredPaymentCancelledEvent({required String walletId, required String txid, required String requestId, required bool success, String? networkStatus, List<String> releasedUtxoKeys = const [], String? error})

Properties

error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
networkStatus → String?
What the network check before the cancellation answered.
final
releasedUtxoKeys → List<String>
Inputs returned to their previous status.
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
txid → String
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited