fee property
The standard policy fee the self-spend pays (ARC's published mining fee for its size). Never raised to outbid anything: on BSV a conflicting transaction cannot be displaced by paying more.
Implementation
final BigInt? fee;
The standard policy fee the self-spend pays (ARC's published mining fee for its size). Never raised to outbid anything: on BSV a conflicting transaction cannot be displaced by paying more.
final BigInt? fee;