failure property

  1. @override
String? get failure
override

Why the request failed, or null when it succeeded. WalletCoordinator.ask throws a CoordinatorFailure carrying this reply when it is not null.

Implementation

@override
String? get failure => success ? null : error ?? 'No source answered';