olderThan property
Only payments recorded more than this long ago (combined with createdBefore: the earlier bound wins).
Implementation
final Duration? olderThan;
Only payments recorded more than this long ago (combined with createdBefore: the earlier bound wins).
final Duration? olderThan;