networkHeight property

int networkHeight
final

The higher of height and the heights the connected peers reported in their version handshake, as LibSpiffyActorSystem.networkHeight; 0 while no peer reported one. A peer's handshake height is from when it connected, so this is for showing progress; synced is the verdict.

Implementation

final int networkHeight;