synced property

bool synced
final

Whether the last answer a peer gave header sync held fewer headers than a full batch (2,000): the peer had nothing more after them. False until the first answer, and while a sync from far behind is still receiving full batches.

Implementation

final bool synced;