HeaderSyncStatusResponse class
Answer to GetHeaderSyncStatusQuery.
- Inheritance
-
- Object
- CoordinatorEvent
- CoordinatorReply
- HeaderSyncStatusResponse
Constructors
- HeaderSyncStatusResponse({String? requestId, required HeaderSyncStatus status})
Properties
- eventTimestamp → DateTime
-
When the event was made.
finalinherited
- failure → String?
-
Never: a failure to answer arrives as an ErrorEvent.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → String?
-
The CoordinatorRequest.requestId of the request this answers; null
when no request caused it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → HeaderSyncStatus
-
final
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited