transactionsFailed property

int transactionsFailed
final

Transactions that could not be fetched or proven, so not recorded. A successful import with this above zero is incomplete: send ImportWalletCommand with resume: true to try them again.

Implementation

final int transactionsFailed;