ImportProgressEvent class

Wallet import progress update

Inheritance

Constructors

ImportProgressEvent({required String walletId, required String phase, required double progress, required String message, int addressesFound = 0, int totalAddresses = 0, int transactionsProcessed = 0, int totalTransactions = 0})

Properties

addressesFound int
final
eventTimestamp DateTime
Timestamp of the event
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
message String
final
phase String
final
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAddresses int
final
totalTransactions int
final
transactionsProcessed int
final
walletId String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited