ImportTransactionConfirmedEvent class

Transaction confirmed by aggregate during import

Inheritance

Constructors

ImportTransactionConfirmedEvent({required String walletId, required String txid, required bool success, String? error})

Properties

error → String?
final
eventTimestamp → DateTime
When the event was made.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
txid → String
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited