InvoicePaidEvent class

Invoice paid

Inheritance

Constructors

InvoicePaidEvent({required String walletId, required String invoiceId, required String txid, required BigInt amountReceived})

Properties

amountReceived → BigInt
final
eventTimestamp → DateTime
When the event was made.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
invoiceId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txid → String
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited