ProvisioningCompleteEvent class

Funding provisioning completed (earmarked UTXOs created).

Inheritance

Constructors

ProvisioningCompleteEvent({String? walletId, required int transactionCount, required int earmarkCount, required bool success, String? error})
ProvisioningCompleteEvent.error({String? walletId, required String errorMessage})

Properties

earmarkCount → int
final
error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
transactionCount → int
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited