memo property
The payment's note, written by the payer for the payee. libspiffy journals it and returns it and never interprets it. Null when none.
Implementation
final String? memo;
The payment's note, written by the payer for the payee. libspiffy journals it and returns it and never interprets it. Null when none.
final String? memo;