blockHash property
The block the proof named, the one that left the active chain; null when the proof never named a block.
Implementation
final String? blockHash;
The block the proof named, the one that left the active chain; null when the proof never named a block.
final String? blockHash;