failure property
Why the request failed, or null when it succeeded.
WalletCoordinator.ask throws a CoordinatorFailure carrying this
reply when it is not null.
Implementation
@override
String? get failure => error;
Why the request failed, or null when it succeeded.
WalletCoordinator.ask throws a CoordinatorFailure carrying this
reply when it is not null.
@override
String? get failure => error;