TransactionImportedEvent class

Transaction imported into wallet

Inheritance

Constructors

TransactionImportedEvent({required String walletId, required String transactionId, required bool success, int? utxosCreated, String? totalValueReceived, String? error, String? requestId})

Properties

error → String?
final
eventTimestamp → DateTime
When the event was made.
finalinherited
failure → String?
Why the request failed, or null when it succeeded. WalletCoordinator.ask throws a CoordinatorFailure carrying this reply when it is not null.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
requestId → String?
The CoordinatorRequest.requestId of the request this answers; null when no request caused it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
totalValueReceived → String?
final
transactionId → String
final
utxosCreated → int?
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited