splits property
How each split transaction that was built and signed ended, in the order the source UTXOs were split.
Implementation
final List<SplitTransactionOutcome> splits;
How each split transaction that was built and signed ended, in the order the source UTXOs were split.
final List<SplitTransactionOutcome> splits;