closing property

bool closing
final

A payment of nothing that a client with no payment closes with, so the server holds a settlement to close the channel with (bead libspiffy-w4l2). Refused on a channel that already has a payment.

Implementation

final bool closing;