feeRate property
ARC's policy rate the server requires: a payment transaction whose fee is below this rate on its signed size is one the server could not get mined, so it is not countersigned (bead libspiffy-zs4l).
Implementation
final FeeRate feeRate;