fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static AllUTXOsSplitCompletedEvent fromMap(Map<String, dynamic> map) {
return AllUTXOsSplitCompletedEvent(
walletId: map['walletId'] as String,
totalUtxosSplit: map['totalUtxosSplit'] as int,
totalOutputsCreated: map['totalOutputsCreated'] as int,
totalFeesPaid: map['totalFeesPaid'] as String,
transactionIds: List<String>.from(map['transactionIds']),
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null
? (map['timestamp'] is String
? DateTime.parse(map['timestamp'] as String)
: map['timestamp'] as DateTime)
: null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);
}