persistenceId property
Unique identifier for this persistent actor Used to store and retrieve events from the event store
Implementation
String get persistenceId => _persistenceId;
Unique identifier for this persistent actor Used to store and retrieve events from the event store
String get persistenceId => _persistenceId;