recoveryComplete property
Future that completes when recovery finishes.
Await this future to wait for the actor to be ready to process commands.
Note: This is only accessible from code that has a direct reference to
the actor instance. For external code using ActorRef, use
RecoveryStatusQuery with ask() instead.
Implementation
Future<void> get recoveryComplete => _recoveryCompleter.future;