events property
The events the command journaled; empty on failure, and empty on an idempotent repeat.
Implementation
final List<Event> events;
The events the command journaled; empty on failure, and empty on an idempotent repeat.
final List<Event> events;