ChannelDetailsQueryMessage class
Asks the channel manager for a channel's full journaled state (the
aggregate is recovered from its journal when not loaded); answered with
FullChannelStateResponse, success: false for an unknown channel.
The P2P adapter rebuilds its channel records from it after a restart
(libspiffy-fsy, libspiffy-36f).
Constructors
- ChannelDetailsQueryMessage({required String channelId})
Properties
- channelId → String
-
final
- correlationId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
no setter
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited