version property
Version/sequence number of this event within its aggregate Used for ordering and optimistic concurrency control
Implementation
int get version => _version;
Version/sequence number of this event within its aggregate Used for ordering and optimistic concurrency control
int get version => _version;