ChannelInitiatedResponse class

Response to channel initiation

Constructors

ChannelInitiatedResponse({required String channelId, required String clientPubKeyHex, required String clientAddressB58, required int derivationIndex, required int lockTimeUnix, required bool success, String? error})

Properties

channelId String
final
clientAddressB58 String
final
clientPubKeyHex String
final
correlationId String
finalinherited
derivationIndex int
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
lockTimeUnix int
final
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
success bool
final
timestamp DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited