fundingFailed property
The sent funding can never be mined (bead libspiffy-4kfq): the channel never opens, and nothing more is sent for it.
Implementation
final bool fundingFailed;
The sent funding can never be mined (bead libspiffy-4kfq): the channel never opens, and nothing more is sent for it.
final bool fundingFailed;