fundingSent property
ARC took the client's funding broadcast (bead libspiffy-jark): the
client sends channel_open and opens when the server says it has.
Implementation
final bool fundingSent;
ARC took the client's funding broadcast (bead libspiffy-jark): the
client sends channel_open and opens when the server says it has.
final bool fundingSent;