isNewerThan method
Check if this state is newer than another state
Implementation
bool isNewerThan(State other) {
return _version > other._version;
}
Check if this state is newer than another state
bool isNewerThan(State other) {
return _version > other._version;
}