isSameVersion method
Check if this state is the same version as another state
Implementation
bool isSameVersion(State other) {
return _version == other._version;
}
Check if this state is the same version as another state
bool isSameVersion(State other) {
return _version == other._version;
}