latestClientSignatureHex property

String? latestClientSignatureHex
final

The client's signature on latestPaymentTxHex, on the client's side: what a close sends with the latest payment, so the server is paid it even when its payment_update was lost.

Implementation

final String? latestClientSignatureHex;