nextVersion method
Create a new version of this state with incremented version
Implementation
State nextVersion([DateTime? timestamp]) {
return copyWith(
version: _version + 1,
lastModified: timestamp ?? DateTime.now(),
);
}
Create a new version of this state with incremented version
State nextVersion([DateTime? timestamp]) {
return copyWith(
version: _version + 1,
lastModified: timestamp ?? DateTime.now(),
);
}