refundTxHex property
The refund template as built (unsigned), or on the server side the refund it signed.
Implementation
final String? refundTxHex;
The refund template as built (unsigned), or on the server side the refund it signed.
final String? refundTxHex;