signedRefundTxHex property
The fully signed refund the client holds, verified against the funding output (libspiffy-b83).
Implementation
final String? signedRefundTxHex;
The fully signed refund the client holds, verified against the funding output (libspiffy-b83).
final String? signedRefundTxHex;