refundTxHex property

String? refundTxHex
final

Raw hex of the refund transaction being claimed (typically the fully signed refund). When null, the refund transaction the channel built is used. Its txid is what the journaled RefundClaimedEvent records.

Implementation

final String? refundTxHex;