fee property
What the half was recorded with, carried over to the completed transaction's record: its fee, payees and payment amount (the coordinator reads them from the half's stored record).
Implementation
final int fee;
What the half was recorded with, carried over to the completed transaction's record: its fee, payees and payment amount (the coordinator reads them from the half's stored record).
final int fee;