bumpHex property

String? bumpHex
final

The hex-encoded BRC-74 BUMP proving the transaction is in the block (ARC's merklePath), journaled with the confirmation so a read model rebuilt from the journal keeps the proof (bead libspiffy-9ek).

Implementation

final String? bumpHex;