CreateInvoiceCommand class

Command to create a new invoice

Inheritance

Constructors

CreateInvoiceCommand({required String invoiceId, required String walletId, required List<String> addresses, required BigInt amount, List<InvoiceOutputSpec>? outputs, String? description, Duration? expiresIn, Map<String, dynamic>? invoiceMetadata})

Properties

addresses → List<String>
Legacy: Pre-generated addresses from wallet (P2PKH only)
final
amount → BigInt
Legacy: Total amount for the invoice
final
commandId → String
Unique identifier for this command Used for deduplication and tracing
no setterinherited
correlationId → String
finalinherited
description → String?
final
effectiveAmount → BigInt
Get effective total amount
no setter
effectiveOutputs → List<InvoiceOutputSpec>
Get effective outputs - either explicit outputs or computed from addresses/amount
no setter
expiresIn → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
invoiceId → String
finalinherited
invoiceMetadata → Map<String, dynamic>?
final
metadata → Map<String, dynamic>
finalinherited
outputs → List<InvoiceOutputSpec>?
Structured output specifications (P2PKH, P2MS, etc.) When present, this takes precedence over addresses/amount
final
payload → dynamic
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
timestamp → DateTime
finalinherited
walletId → String
final

Methods

getValidationErrors() → List<String>
Get validation errors Override in subclasses to provide specific error messages
inherited
isValid() → bool
Validate the command Override in subclasses for custom validation
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() → List<int>
Serialize command to CBOR bytes
inherited
toMap() → Map<String, dynamic>
Convert command to a map for serialization Override in subclasses to include command-specific data
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited