fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static DeferredSpendCompletedEvent fromMap(Map<String, dynamic> map) => DeferredSpendCompletedEvent(
walletId: map['walletId'] as String,
txid: map['txid'] as String,
completedTxid: map['completedTxid'] as String,
completedUtxoKeys: [for (final k in (map['completedUtxoKeys'] as List? ?? const [])) k.toString()],
eventId: map['eventId'] as String?,
timestamp: _deferredDate(map['timestamp']),
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);