networkStatus property
The status the network check before the cancellation returned (null when the cancellation did not check, e.g. a payment never handed over).
Implementation
final String? networkStatus;
The status the network check before the cancellation returned (null when the cancellation did not check, e.g. a payment never handed over).
final String? networkStatus;