fundingRecordedInWallet property
Whether the funding transaction is already recorded in the client wallet by an earlier broadcast attempt.
Implementation
final bool fundingRecordedInWallet;
Whether the funding transaction is already recorded in the client wallet by an earlier broadcast attempt.
final bool fundingRecordedInWallet;