fundingSent property
ARC took the client's funding; the server has not opened yet, or has (bead libspiffy-jark).
Implementation
final bool fundingSent;
ARC took the client's funding; the server has not opened yet, or has (bead libspiffy-jark).
final bool fundingSent;