latestPaymentTxHex property

String? latestPaymentTxHex
final

The latest payment transaction of the channel. On the server (which holds both signatures when it acknowledges) this is the fully signed settlement; on the client it is the unsigned template it signed, whose txid is not the one the signed transaction will have. Null before the first payment. Read by the close path to find the transaction that ends the channel (bead libspiffy-f5p2).

Implementation

final String? latestPaymentTxHex;