returnLegRecordedInWallet property
Whether this side's wallet already holds the transaction that ended the channel and paid it back (bead libspiffy-lfrv).
Implementation
final bool returnLegRecordedInWallet;
Whether this side's wallet already holds the transaction that ended the channel and paid it back (bead libspiffy-lfrv).
final bool returnLegRecordedInWallet;