signedRefundTxHex property

String? signedRefundTxHex
final

The fully signed refund transaction the client holds (null until the server's signature is verified, and on the server side).

Implementation

final String? signedRefundTxHex;