fundingBeefHex property
The funding transaction with its ancestors and their merkle proofs, for the server to SPV-validate (libspiffy-fsy).
Implementation
final String? fundingBeefHex;
The funding transaction with its ancestors and their merkle proofs, for the server to SPV-validate (libspiffy-fsy).
final String? fundingBeefHex;