InitiateChannelMessage class

Request to initiate a new payment channel as client

Constructors

InitiateChannelMessage({required String channelId, required String walletId, required String clientPeerId, required String serverPeerId, required BigInt fundingAmountSats, required int lockTimeDurationSeconds, String? context})

Properties

channelId → String
final
clientPeerId → String
final
context → String?
final
correlationId → String
finalinherited
fundingAmountSats → BigInt
final
hashCode → int
The hash code for this object.
no setterinherited
lockTimeDurationSeconds → int
final
metadata → Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverPeerId → String
final
timestamp → DateTime
finalinherited
walletId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited