commandHandler method

  1. @override
Future<void> commandHandler(
  1. Command command
)
inherited

Process a command through the full pipeline This is the main entry point for command processing.

Sequential execution is guaranteed by the lock in PersistentActor._handleCommand, which wraps this method.

Implementation

@override
Future<void> commandHandler(Command command) async {
  _journalWriteStarted = false;
  await super.commandHandler(command);
  _journalWriteStarted = false;
}