createInitialState method
Create the initial state for this aggregate Override in subclasses to provide the initial state
Implementation
@override
InvoiceState createInitialState() {
return InvoiceState.empty(aggregateId);
}
Create the initial state for this aggregate Override in subclasses to provide the initial state
@override
InvoiceState createInitialState() {
return InvoiceState.empty(aggregateId);
}