createInitialState method
Create the initial state for this aggregate Override in subclasses to provide the initial state
Implementation
@override
ChannelState createInitialState() => ChannelState.empty(aggregateId);
Create the initial state for this aggregate Override in subclasses to provide the initial state
@override
ChannelState createInitialState() => ChannelState.empty(aggregateId);