isOutOfService property
True once an infrastructure failure has taken this incarnation out of service.
Implementation
@visibleForTesting
bool get isOutOfService => _outOfService;
True once an infrastructure failure has taken this incarnation out of service.
@visibleForTesting
bool get isOutOfService => _outOfService;