onEventApplied method
Called after an event has been applied to the state Override to perform post-event application actions
Implementation
@protected
void onEventApplied(Event event, TState newState) {}
Called after an event has been applied to the state Override to perform post-event application actions
@protected
void onEventApplied(Event event, TState newState) {}