onRecoveryComplete method
Called when recovery is complete Override to perform post-recovery initialization
Implementation
@protected
Future<void> onRecoveryComplete() async {}
Called when recovery is complete Override to perform post-recovery initialization
@protected
Future<void> onRecoveryComplete() async {}