queryHandler method
Handles incoming queries or other non-persistent messages.
Override this method to handle messages that do not result in state changes, such as requests for the current state.
Implementation
@protected
Future<void> queryHandler(dynamic message) async {
// Default implementation - subclasses should override
}