postStop method
Stop the channel aggregates this manager spawned, so a host-owned actor system does not keep them running after libspiffy shuts down.
Implementation
@override
void postStop() {
final system = context.system;
for (final ref in _channelAggregates.values) {
unawaited(system.stop(ref));
}
_channelAggregates.clear();
}