fullySignedPaymentTxId property
Its txid — the one the signed transaction really has, which the template's is not.
Implementation
final String fullySignedPaymentTxId;
Its txid — the one the signed transaction really has, which the template's is not.
final String fullySignedPaymentTxId;