PaymentRecordedEvent class
Payment has been recorded (client side - built and signed)
- Inheritance
-
- Object
- ChannelEvent
- PaymentRecordedEvent
Constructors
-
PaymentRecordedEvent({required String channelId, required BigInt amountSats, required BigInt newClientBalanceSats, required BigInt newServerBalanceSats, required int sequenceNumber, required String paymentTxHex, required String paymentTxId, required String clientSignatureHex, String? purpose, String? invoiceId, String? eventId, DateTime? timestamp, int? version, Map<
String, dynamic> ? metadata}) -
PaymentRecordedEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- amountSats → BigInt
-
final
- channelId → String
-
finalinherited
- clientSignatureHex → String
-
final
- correlationId → String
-
The correlation ID of the message.
no setterinherited
- eventId → String
-
Unique identifier for this event
Used for deduplication and correlation
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceId → String?
-
final
-
metadata
→ Map<
String, dynamic> -
Additional metadata for the event
Can include correlation IDs, causation IDs, user context, etc.
no setterinherited
- newClientBalanceSats → BigInt
-
final
- newServerBalanceSats → BigInt
-
final
- paymentTxHex → String
-
final
- paymentTxId → String
-
final
- purpose → String?
-
final
- replyTo → ActorRef?
-
The actor to reply to.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber → int
-
final
- timestamp → DateTime
-
Timestamp when the event occurred
no setterinherited
- version → int
-
Version/sequence number of this event within its aggregate
Used for ordering and optimistic concurrency control
no setterinherited
Methods
-
getChannelEventData(
) → Map< String, dynamic> -
Override to provide event-specific data for serialization
override
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the event
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize event to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert event to a map for serialization
Override in subclasses to include event-specific data
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited