PaymentRecordedResponse class
Response to payment recording
- Inheritance
-
- Object
- ActorResponse
- PaymentRecordedResponse
Constructors
Properties
- amountSats → BigInt
-
final
- channelId → String
-
final
- clientSignatureHex → String
-
final
- correlationId → String
-
finalinherited
- error → String?
-
Why the request failed; null when success is true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- newClientBalanceSats → BigInt
-
final
- newServerBalanceSats → BigInt
-
final
- payload → dynamic
-
The reply itself, so
ask<ConcreteResponse>()completes with it.no setterinherited - paymentTxHex → String
-
final
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- sequenceNumber → int
-
final
- success → bool
-
Whether the request this reply answers succeeded.
final
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited