RecordFundingFailedMessage class

The wallet failed the client's sent funding fundingTxId of channelId: it can never be mined (bead libspiffy-4kfq). The manager journals it (RecordFundingFailedCommand); nothing is answered.

Constructors

RecordFundingFailedMessage({required String channelId, required String fundingTxId, required String reason})

Properties

channelId → String
final
correlationId → String
finalinherited
fundingTxId → String
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
finalinherited
payload → dynamic
no setter
reason → String
final
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
timestamp → DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited