blockHeight property
The block a verified merkle proof puts the transaction in; null when it came with no proof (bead libspiffy-nys0). Set together with bumpProofHex.
Implementation
final int? blockHeight;
The block a verified merkle proof puts the transaction in; null when it came with no proof (bead libspiffy-nys0). Set together with bumpProofHex.
final int? blockHeight;