deadline property
With deferSpend: when the wallet reclaims the payment by itself if it is still outstanding then (bead libspiffy-8442). Null for never.
Implementation
final DateTime? deadline;
With deferSpend: when the wallet reclaims the payment by itself if it is still outstanding then (bead libspiffy-8442). Null for never.
final DateTime? deadline;