feeRate property
ARC's policy rate the client built the payment transaction at: its fee must be at least this rate on its signed size (bead libspiffy-zs4l).
Implementation
final FeeRate feeRate;
ARC's policy rate the client built the payment transaction at: its fee must be at least this rate on its signed size (bead libspiffy-zs4l).
final FeeRate feeRate;