closing property
The payment of nothing a client with no payment closes with (bead libspiffy-w4l2); amountSats is zero.
Implementation
final bool closing;
The payment of nothing a client with no payment closes with (bead libspiffy-w4l2); amountSats is zero.
final bool closing;