RecordServerAcceptanceCommand class
Client records that the server accepted the channel
This command is used by the client after receiving the server's acceptance via P2P. It updates the client's aggregate with the server's public key and address for building transactions.
- Inheritance
-
- Object
- ChannelCommand
- RecordServerAcceptanceCommand
Constructors
Properties
- channelId → String
-
finalinherited
- commandId → String
-
Unique identifier for this command
Used for deduplication and tracing
no setterinherited
- commandType → String
-
no setteroverride
- correlationId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
-
persistableMetadata
→ Map<
String, dynamic> -
metadataas it is persisted: transientActorRefentries removed.no setterinherited - replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- serverAddressB58 → String
-
final
- serverPubKeyHex → String
-
final
- timestamp → DateTime
-
finalinherited
- typeName → String
-
Stable identity of this command type in storage.
no setterinherited
Methods
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the command
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize command to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert command to a map for serialization.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited