RecordServerAcceptanceMessage class

Client records that server accepted the channel (stores server pubkey/address)

Constructors

RecordServerAcceptanceMessage({required String channelId, required String serverPubKeyHex, required String serverAddressB58})

Properties

channelId → String
final
correlationId → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverAddressB58 → String
final
serverPubKeyHex → String
final
timestamp → DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited