signedRefundTxHex property
The fully signed refund transaction (client side). Null on the server side and in rows written before libspiffy-b83.
Implementation
final String? signedRefundTxHex;
The fully signed refund transaction (client side). Null on the server side and in rows written before libspiffy-b83.
final String? signedRefundTxHex;