RefundTransactionSignedResponse class

Response with refund signature

Constructors

RefundTransactionSignedResponse({required String channelId, required String serverSignatureHex, required bool success, String? error})

Properties

channelId String
final
correlationId String
finalinherited
error String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverSignatureHex String
final
success bool
final
timestamp DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited