toMap method

  1. @override
Map<String, dynamic> toMap()

Convert command to a map for serialization.

Override in subclasses to include command-specific data. This is used by the saga command queue codec, so it is part of the public surface.

Implementation

@override
Map<String, dynamic> toMap() {
  return {
    ...super.toMap(),
    'address': address,
    'derivationIndex': derivationIndex,
    'chain': chain.index,
    'transactionCount': transactionCount,
  };
}