subscriptHex property

String subscriptHex
final

Script the signature commits to: the locking script of the output being spent (or the part of it after the last executed OP_CODESEPARATOR).

Implementation

final String subscriptHex;