minPartSats property
No piece is smaller than this: a UTXO makes fewer pieces, or is not split when it cannot make two (bead libspiffy-5hnt). Null for no minimum.
Implementation
final BigInt? minPartSats;
No piece is smaller than this: a UTXO makes fewer pieces, or is not split when it cannot make two (bead libspiffy-5hnt). Null for no minimum.
final BigInt? minPartSats;