fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static TransactionConfirmedEvent fromMap(Map<String, dynamic> map) {
return TransactionConfirmedEvent(
walletId: map['walletId'] as String,
txid: map['txid'] as String,
blockHeight: map['blockHeight'] as int?,
blockHash: map['blockHash'] as String?,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null
? (map['timestamp'] is String
? DateTime.parse(map['timestamp'] as String)
: map['timestamp'] as DateTime)
: null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);
}