ancestors property
For a transaction received unproven (empty bumpProof): the ancestors its BEEF carried back to proven transactions, with their BUMPs, parents first (bead libspiffy-zsh). Empty for a proven transaction and for rows journaled before the field existed (the key is written only when not empty, so such rows and events without ancestors serialize as before).
Implementation
final List<BeefAncestor> ancestors;