reactivated property
True when the same transaction, a cancelled deferred payment, was recorded again with a deferred spend: the payment is outstanding again and holds heldInputs. The cancellation stays in the journal before it (bead libspiffy-4r0).
Implementation
final bool reactivated;