fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static Type42DestinationDerivedEvent fromMap(Map<String, dynamic> map) => Type42DestinationDerivedEvent(
walletId: map['walletId'] as String,
destination: Type42Destination.fromMap(map)!,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] == null
? null
: map['timestamp'] is DateTime
? map['timestamp'] as DateTime
: DateTime.parse(map['timestamp'] as String),
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);