restoredStatus property
Status the UTXO returns to: the status it had before it was reserved (audit 2026-09-14 M4). Null on events journaled before this field existed, which released to UTXOStatus.available.
Implementation
final UTXOStatus? restoredStatus;