fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static UTXOSplitCompletedEvent fromMap(Map<String, dynamic> map) {
return UTXOSplitCompletedEvent(
walletId: map['walletId'] as String,
originalUtxoKey: map['originalUtxoKey'] as String,
originalAmount: map['originalAmount'] as String,
splitTxid: map['splitTxid'] as String,
outputsCreated: map['outputsCreated'] as int,
feePaid: map['feePaid'] as String,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null
? (map['timestamp'] is String
? DateTime.parse(map['timestamp'] as String)
: map['timestamp'] as DateTime)
: null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);
}