payload property
Override payload to return the command itself for LocalMessage compatibility
Implementation
@override
dynamic get payload => this;
Override payload to return the command itself for LocalMessage compatibility
@override
dynamic get payload => this;