isComplete property
bool
get
isComplete
True when every transaction found for the wallet is recorded.
Implementation
bool get isComplete => transactionsFailed == 0;
True when every transaction found for the wallet is recorded.
bool get isComplete => transactionsFailed == 0;