WalletImportFailedEvent class

The import failed or was cancelled (metadata['cancelled'] == true).

Inheritance

Constructors

WalletImportFailedEvent({required String walletId, required String error, String? partialProgress, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

error → String
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
Free-form details (for example {'cancelled': true} on a failure).
finalinherited
partialProgress → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
When the notification was raised.
finalinherited
walletId → String
Wallet being imported.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited