WalletImportProgressEvent class

Periodic progress of a running import.

Inheritance

Constructors

WalletImportProgressEvent({required String walletId, required String phase, required String message, required double progress, required int addressesFound, required int totalAddresses, required int transactionsProcessed, required int totalTransactions, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

addressesFound → int
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
metadata → Map<String, dynamic>
Free-form details (for example {'cancelled': true} on a failure).
finalinherited
phase → String
final
progress → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
When the notification was raised.
finalinherited
totalAddresses → int
final
totalTransactions → int
final
transactionsProcessed → int
final
walletId → String
Wallet being imported.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited