WalletImportStartedEvent class
An import job has created (or confirmed) the wallet and is starting.
- Inheritance
-
- Object
- WalletImportNotification
- WalletImportStartedEvent
Constructors
Properties
- addressGapLimit → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Free-form details (for example
{'cancelled': true}on a failure).finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the notification was raised.
finalinherited
- walletId → String
-
Wallet being imported.
finalinherited
- walletName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited