WalletImportTransactionConfirmedEvent class

The wallet aggregate acknowledged (or rejected) an imported transaction.

Inheritance

Constructors

WalletImportTransactionConfirmedEvent({required String walletId, required String txid, required bool success, String? error, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
Free-form details (for example {'cancelled': true} on a failure).
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
timestamp → DateTime
When the notification was raised.
finalinherited
txid → String
final
walletId → String
Wallet being imported.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited