fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static WatchAddressAddedEvent fromMap(Map<String, dynamic> map) => WatchAddressAddedEvent(
walletId: map['walletId'] as String,
address: map['address'] as String,
scriptType: map['scriptType'] as String,
label: map['label'] as String?,
registeredAt: _date(map['registeredAt']),
reconciled: map['reconciled'] as bool? ?? false,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null ? _date(map['timestamp']) : null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);