BroadcastDeferredPaymentMessage class

Asks ARCActor to broadcast the deferred payment txid itself: the unproven transactions of beefHex (its unconfirmed ancestors) first, then rawTxHex. Idempotent. Replied with DeferredPaymentNetworkResult.

Constructors

BroadcastDeferredPaymentMessage({required String walletId, required String txid, required String rawTxHex, String? beefHex, DeferredPaymentNetworkSource via = DeferredPaymentNetworkSource.arc})

Properties

beefHex → String?
final
correlationId → String
The correlation ID of the message.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
The metadata of the message.
no setter
rawTxHex → String
final
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The timestamp of the message.
no setter
txid → String
final
via → DeferredPaymentNetworkSource
final
walletId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited