DeferredPaymentPage class

One page of deferred payments.

Constructors

DeferredPaymentPage({required List<DeferredPayment> payments, String? nextCursor})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextCursor → String?
Pass as DeferredPaymentQuery.cursor for the next page; null when this is the last page.
final
payments → List<DeferredPayment>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited