Leaf class

Represents a leaf in the merkle tree

Constructors

Leaf({required int offset, required bool duplicate, required bool isTxid, Uint8List? hash})
Creates a new Leaf instance

Properties

duplicate bool
Whether to duplicate the working hash
final
hash Uint8List?
A hash representing a txid, sibling hash, or a branch
final
hashCode int
The hash code for this object.
no setterinherited
isTxid bool
Whether the hash is a relevant txid
final
offset int
Offset from left hand side within tree
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited