SetInvoiceManagerMessage class

Internal message to set InvoiceManager reference in WalletManager

Constructors

SetInvoiceManagerMessage(ActorRef invoiceManager)

Properties

correlationId String
The correlation ID of the message.
no setter
hashCode int
The hash code for this object.
no setterinherited
invoiceManager → ActorRef
final
metadata Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited