StorageFactory class

Factory for creating storage instances based on the selected backend.

This class provides methods to create both read model storage and event store implementations for the specified backend.

Constructors

StorageFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createEventStore({required StorageBackend backend, Isar? isar, PostgresConfig? postgresConfig}) Future<EventStore>
Creates an EventStore instance for the specified backend.
createReadModelStorage({required StorageBackend backend, Isar? isar, IsolateConfig? isolateConfig, PostgresConfig? postgresConfig}) Future<ReadModelStorage>
Creates a ReadModelStorage instance for the specified backend.
createStorages({required StorageBackend backend, Isar? isar, IsolateConfig? isolateConfig, PostgresConfig? postgresConfig}) Future<({EventStore eventStore, ReadModelStorage readModel})>
Creates both read model storage and event store for the specified backend.