walletId property
String
get
walletId
ID of the wallet this event belongs to (same as aggregateId)
Implementation
String get walletId => aggregateId;
ID of the wallet this event belongs to (same as aggregateId)
String get walletId => aggregateId;