AnchorSignedEvent class

Answer to SignWithAnchorKeyCommand: the DER signature (hex) of SHA-256 of the message by the anchor key publicKey, or why there is none. The signature is deterministic (RFC 6979) with a low S.

Inheritance

Constructors

AnchorSignedEvent({required String walletId, required String requestId, String? publicKey, String? signatureDer, required bool success, String? error})

Properties

error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
publicKey → String?
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureDer → String?
final
success → bool
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited