BEEFValidationResultEvent class

BEEF validation result

Inheritance

Constructors

BEEFValidationResultEvent({String? walletId, String? invoiceId, String? txid, required bool valid, String? error, bool broadcasted = false, List<Map<String, dynamic>>? spendableUTXOs})

Properties

broadcasted bool
final
error String?
final
eventTimestamp DateTime
Timestamp of the event
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spendableUTXOs List<Map<String, dynamic>>?
final
txid String?
final
valid bool
final
walletId String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited