BalanceUpdatedEvent class

Balance updated asynchronously (e.g., new UTXO received)

Inheritance

Constructors

BalanceUpdatedEvent({required String walletId, required BigInt confirmedBalance, required BigInt unconfirmedBalance, required BigInt totalBalance})

Properties

confirmedBalance BigInt
final
eventTimestamp DateTime
Timestamp of the event
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBalance BigInt
final
unconfirmedBalance BigInt
final
walletId String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited