BlockHeadersStoredEvent class

Block headers stored

Inheritance

Constructors

BlockHeadersStoredEvent({required int headersStored, required int startHeight, required int endHeight, required bool success, String? error})

Properties

endHeight int
final
error String?
final
eventTimestamp DateTime
Timestamp of the event
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
headersStored int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startHeight int
final
success bool
final
walletId String?
Optional wallet ID for filtering events by wallet
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited