BroadcastFailureEvent class

Broadcast to Arc failed (transaction queued for retry via duraq)

Inheritance

Constructors

BroadcastFailureEvent({String? walletId, required String txid, required String error, bool willRetry = true})

Properties

error → String
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txid → String
final
walletId → String?
Optional wallet ID for filtering events by wallet
final
willRetry → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited