ChannelFundingRetriedEvent class

another retry.

Inheritance

Constructors

ChannelFundingRetriedEvent({String? walletId, required String channelId, String? fundingTxId, required bool success, String? error})

Properties

channelId → String
final
error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
fundingTxId → String?
The funding transaction that was re-broadcast; null when the retry was refused before one was read from the channel's state.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited