ChannelOpenedEvent class

Channel opened successfully

Inheritance

Constructors

ChannelOpenedEvent({required String walletId, required String channelId, String? fundingTxId, required int fundingAmountSats})

Properties

channelId String
final
eventTimestamp DateTime
Timestamp of the event
no setteroverride
fundingAmountSats int
final
fundingTxId String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletId String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited