ChannelP2PReceived class

Incoming P2P message for a payment channel

Constructors

ChannelP2PReceived({required String fromPeerId, required String messageType, required Map<String, dynamic> payload})

Properties

correlationId → String
The correlation ID of the message.
no setter
fromPeerId → String
final
hashCode → int
The hash code for this object.
no setterinherited
messageType → String
final
metadata → Map<String, dynamic>
The metadata of the message.
no setter
payload → Map<String, dynamic>
final
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
The timestamp of the message.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited