ChannelPaymentEvent class

Payment made or received on a channel

Inheritance

Constructors

ChannelPaymentEvent({String? walletId, required String channelId, required int amountSats, required int sequence, required int clientBalance, required int serverBalance, String? requestId})

Properties

amountSats → int
final
channelId → String
final
clientBalance → int
final
eventTimestamp → DateTime
When the event was made.
finalinherited
failure → String?
Never: a failure to answer arrives as an ErrorEvent.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
requestId → String?
The CoordinatorRequest.requestId of the request this answers; null when no request caused it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int
final
serverBalance → int
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited