ChannelPaymentEvent class

Payment made or received on a channel

Inheritance

Constructors

ChannelPaymentEvent({String? walletId, required String channelId, required int amountSats, required int sequence, required int clientBalance, required int serverBalance})

Properties

amountSats → int
final
channelId → String
final
clientBalance → int
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int
final
serverBalance → int
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited