ChannelRequestReceivedEvent class
Incoming channel request from a peer (app should show UI for approval)
- Inheritance
-
- Object
- CoordinatorEvent
- ChannelRequestReceivedEvent
Constructors
Properties
- channelId → String
-
final
- clientAddress → String
-
final
- clientPeerId → String
-
final
- clientPubKey → String
-
final
- context → String?
-
final
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- fundingAmountSats → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockTimeUnix → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited