CoordinatorEvent class abstract
Base class for all coordinator events emitted on the event stream.
Third-party apps subscribe to Stream<CoordinatorEvent> to receive
async results from the coordinator.
- Implementers
- BalanceResponse
- BalanceUpdatedEvent
- BEEFValidationResultEvent
- BlockHeadersStoredEvent
- ChannelClosedEvent
- ChannelOpenedEvent
- ChannelP2PMessageToSendEvent
- ChannelPaymentEvent
- ChannelRequestReceivedEvent
- ErrorEvent
- HeaderSyncProgressEvent
- ImportCompleteEvent
- ImportProgressEvent
- InvoiceCreatedEvent
- InvoicePaidEvent
- PaymentReadyEvent
- SPVValidationResultEvent
- TimestampCompleteEvent
- TransactionConfirmedEvent
- TransactionDetailResponse
- TransactionImportedEvent
- TransactionReceivedEvent
- TransactionsResponse
- UTXOSplitCompleteEvent
- UTXOSplitStartedEvent
- WalletCreatedEvent
- WalletStatusEvent
- WatchAddressRegisteredEvent
Constructors
Properties
- eventTimestamp → DateTime
-
Timestamp of the event
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited