defaultTimeout constant
Duration
const defaultTimeout
A request the coordinator answers from its own state, or after one round trip to the wallet (each of which waits up to 30 s).
Implementation
static const defaultTimeout = Duration(minutes: 1);