CreateInvoiceCommand class
Create a payment invoice
Constructors
Properties
- amount → BigInt?
-
final
- correlationId → String
-
The correlation ID of the message.
no setter
- description → String?
-
final
- effectiveExpiresIn → Duration?
-
Effective expiry duration
no setter
- expiresIn → Duration?
-
final
- expiresInSeconds → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
invoiceMetadata
→ Map<
String, dynamic> ? -
final
-
metadata
→ Map<
String, dynamic> -
The metadata of the message.
no setter
- numberOfAddresses → int
-
final
-
outputs
→ List<
InvoiceOutputSpec> ? -
final
- replyTo → ActorRef?
-
The actor to reply to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The timestamp of the message.
no setter
- walletId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited