DeferredPaymentBroadcastEvent class
Result of BroadcastDeferredPaymentCommand.
- Inheritance
-
- Object
- CoordinatorEvent
- DeferredPaymentBroadcastEvent
Constructors
Properties
-
competingTxids
→ List<
String> -
The competing transactions ARC named with a DOUBLE_SPEND_ATTEMPTED
answer (bead libspiffy-pkum); empty otherwise.
final
- confirmed → bool
-
A MINED answer's merkle proof checked against the local headers
confirmed the transaction.
final
- error → String?
-
final
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkStatus → String?
-
The source's last answer (
SEEN_ON_NETWORK,MINED,REJECTED, ...).final - requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
arcordataSource.final - success → bool
-
The network holds the transaction (
SEEN_ON_NETWORKorMINED), or already did. An answer ARC gave in flight (it stopped waiting for the network) is followed for up to 30 s until ARC gives a verdict; one still in flight then, in the orphan mempool, contested or rejected is not a success, and error says why.final - txid → String
-
final
- walletId → String
-
Optional wallet ID for filtering events by wallet
final
- willRetry → bool
-
The failed broadcast was queued for a durable retry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited