DeferredPaymentsResponse class
Answer to GetDeferredPaymentsQuery.
- Inheritance
-
- Object
- CoordinatorEvent
- DeferredPaymentsResponse
Constructors
-
DeferredPaymentsResponse({required String walletId, required String queryId, required List<
DeferredPaymentDetail> payments, String? nextCursor})
Properties
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCursor → String?
-
Pass as GetDeferredPaymentsQuery.cursor for the next page; null on
the last page.
final
-
payments
→ List<
DeferredPaymentDetail> -
final
- queryId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- walletId → String
-
Optional wallet ID for filtering events by wallet
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited