HeaderSyncProgressEvent class
CDN/P2P header sync progress
- Inheritance
-
- Object
- CoordinatorEvent
- HeaderSyncProgressEvent
Constructors
- HeaderSyncProgressEvent({required int currentHeight, required int totalHeight, required String phase})
Properties
- currentHeight → int
-
final
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- phase → String
-
final
- progress → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalHeight → int
-
final
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited