HeaderSyncStatusEvent class
Header sync caught up with its peers, or fell behind them: emitted when HeaderSyncStatus.synced changes. Each batch of headers stored on the way is a BlockHeadersStoredEvent.
- Inheritance
-
- Object
- CoordinatorEvent
- HeaderSyncStatusEvent
Constructors
- HeaderSyncStatusEvent({required HeaderSyncStatus status})
Properties
- eventTimestamp → DateTime
-
When the event was made.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → HeaderSyncStatus
-
final
- walletId → String?
-
Optional wallet ID for filtering events by wallet
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited