ImportCompleteEvent class

Wallet import completed

Inheritance

Constructors

ImportCompleteEvent({required String walletId, required bool success, String? error, int addressCount = 0, int transactionCount = 0})

Properties

addressCount → int
final
error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
transactionCount → int
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited