ImportTransactionCommand class

Import a transaction into the wallet

Constructors

ImportTransactionCommand({required String walletId, required String transactionId, required List<int> beef, String? fromCounterparty})

Properties

beef List<int>
final
correlationId String
The correlation ID of the message.
no setter
fromCounterparty String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter
transactionId String
final
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited