ImportWalletCommand class

Import a wallet from extended private key or WIF

Constructors

ImportWalletCommand({required String walletId, required String walletName, String? xpriv, String? mnemonic, String? wif, int gapLimit = 20, String networkType = 'test'})

Properties

correlationId String
The correlation ID of the message.
no setter
gapLimit int
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
The metadata of the message.
no setter
mnemonic String?
final
networkType String
final
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter
walletId String
final
walletName String
final
wif String?
final
xpriv String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited