InvoiceCreatedEvent class
Invoice created successfully
- Inheritance
-
- Object
- CoordinatorEvent
- InvoiceCreatedEvent
Constructors
Properties
-
addresses
→ List<
String> -
final
- amount → BigInt
-
final
- description → String?
-
final
- error → String?
-
final
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceId → String
-
final
-
outputs
→ List<
InvoiceOutputSpec> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
- walletId → String
-
Optional wallet ID for filtering events by wallet
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited