OpenChannelCommand class

Open a payment channel with a peer

Constructors

OpenChannelCommand({required String walletId, required String serverPeerId, required int fundingAmountSats, required int lockTimeDurationSeconds, String? context})

Properties

context → String?
final
correlationId → String
The correlation ID of the message.
no setter
fundingAmountSats → int
final
hashCode → int
The hash code for this object.
no setterinherited
lockTimeDurationSeconds → int
final
metadata → Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverPeerId → String
final
timestamp → DateTime
The timestamp of the message.
no setter
walletId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited