PayInvoiceCommand class
Pay an invoice (builds BEEF, does NOT broadcast)
Constructors
Properties
-
addresses
→ List<
String> -
final
- amount → BigInt
-
final
- changeAddress → String?
-
final
- correlationId → String
-
The correlation ID of the message.
no setter
- feeEstimateSats → BigInt?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceId → String
-
final
-
metadata
→ Map<
String, dynamic> -
The metadata of the message.
no setter
-
outputs
→ List<
InvoiceOutputSpec> ? -
final
-
paymentMetadata
→ Map<
String, dynamic> ? -
final
- replyTo → ActorRef?
-
The actor to reply to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The timestamp of the message.
no setter
- walletId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited