PaymentReadyEvent class
BEEF payment constructed and ready for transmission to counterparty
- Inheritance
-
- Object
- CoordinatorEvent
- CoordinatorReply
- PaymentReadyEvent
Constructors
- PaymentReadyEvent({String? walletId, required String invoiceId, required Uint8List beefBytes, required String txid, required BigInt amountPaid, required BigInt changeAmount, required int ancestorCount, required bool success, String? error, String? witnessTxid, Uint8List? witnessBeefBytes, String? requestId})
Properties
- amountPaid → BigInt
-
final
- ancestorCount → int
-
final
- beefBytes → Uint8List
-
final
- changeAmount → BigInt
-
final
- error → String?
-
final
- eventTimestamp → DateTime
-
When the event was made.
finalinherited
- failure → String?
-
Why the request failed, or null when it succeeded.
WalletCoordinator.askthrows a CoordinatorFailure carrying this reply when it is not null.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceId → String
-
final
- requestId → String?
-
The CoordinatorRequest.requestId of the request this answers; null
when no request caused it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
- txid → String
-
final
- walletId → String?
-
Optional wallet ID for filtering events by wallet
final
- witnessBeefBytes → Uint8List?
-
Serialized BEEF for the witness transaction (null if no paired witness).
final
- witnessTxid → String?
-
Witness transaction ID (null if no paired witness).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited