PaymentReadyEvent class

BEEF payment constructed and ready for transmission to counterparty

Inheritance

Constructors

PaymentReadyEvent({String? walletId, required String invoiceId, required Uint8List beefBytes, required String txid, required BigInt amountPaid, required BigInt changeAmount, required int ancestorCount, required bool success, String? error})
PaymentReadyEvent.error({String? walletId, required String invoiceId, required String errorMessage})

Properties

amountPaid → BigInt
final
ancestorCount → int
final
beefBytes → Uint8List
final
changeAmount → BigInt
final
error → String?
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
invoiceId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
txid → String
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited