RecordOutgoingCommand class

Record an outgoing transaction in the wallet

Constructors

RecordOutgoingCommand({required String walletId, required String txid, required String rawHex, required int totalInputSats, required int totalOutputSats, required int fee, required int numInputs, required int numOutputs, required int txVersion, required int txLockTime, required List<String> spentUtxoKeys, required List<String> recipientAddresses, required int paymentAmount, String? changeAddress, int? changeAmount})

Properties

changeAddress String?
final
changeAmount int?
final
correlationId String
The correlation ID of the message.
no setter
fee int
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
The metadata of the message.
no setter
numInputs int
final
numOutputs int
final
paymentAmount int
final
rawHex String
final
recipientAddresses List<String>
final
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spentUtxoKeys List<String>
final
timestamp DateTime
The timestamp of the message.
no setter
totalInputSats int
final
totalOutputSats int
final
txid String
final
txLockTime int
final
txVersion int
final
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited