SPVValidationResultEvent class

SPV validation result for a received transaction

Inheritance

Constructors

SPVValidationResultEvent({String? walletId, required String txid, required bool isValid, String? validationError, List<Map<String, dynamic>> spendableUTXOs = const [], List<Map<String, dynamic>> spentUTXOs = const []})

Properties

eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spendableUTXOs → List<Map<String, dynamic>>
final
spentUTXOs → List<Map<String, dynamic>>
final
txid → String
final
validationError → String?
final
walletId → String?
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited