SplitUTXOsCommand class

Split UTXOs using Benford's Law distribution for privacy

Constructors

SplitUTXOsCommand({required String walletId, int? targetUtxoCount, int? feeRateSatsPerByte, int? maxUtxosToSplit})

Properties

correlationId String
The correlation ID of the message.
no setter
feeRateSatsPerByte int?
final
hashCode int
The hash code for this object.
no setterinherited
maxUtxosToSplit int?
final
metadata Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetUtxoCount int?
final
timestamp DateTime
The timestamp of the message.
no setter
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited