TimestampCommand class

Create a timestamp archive (OP_RETURN data on-chain)

Constructors

TimestampCommand({required String archiveId, required String walletId, required List<String> fileHashes, String? archiveTitle})

Properties

archiveId String
final
archiveTitle String?
final
correlationId String
The correlation ID of the message.
no setter
fileHashes List<String>
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
The metadata of the message.
no setter
replyTo → ActorRef?
The actor to reply to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp of the message.
no setter
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited