TransactionConfirmedEvent class

Transaction confirmed on-chain

Inheritance

Constructors

TransactionConfirmedEvent({required String walletId, required String txid, required int blockHeight, int confirmations = 1})

Properties

blockHeight → int
final
confirmations → int
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txid → String
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited