TransactionDetailResponse class
Transaction detail query response
- Inheritance
-
- Object
- CoordinatorEvent
- CoordinatorReply
- TransactionDetailResponse
Constructors
- TransactionDetailResponse({required String walletId, String? requestId, BitcoinTransaction? transaction, bool found = true, String? error})
Properties
- error → String?
-
final
- eventTimestamp → DateTime
-
When the event was made.
finalinherited
- failure → String?
-
Why the request failed, or null when it succeeded.
WalletCoordinator.askthrows a CoordinatorFailure carrying this reply when it is not null.no setteroverride - found → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → String?
-
The CoordinatorRequest.requestId of the request this answers; null
when no request caused it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → BitcoinTransaction?
-
final
- walletId → String
-
Optional wallet ID for filtering events by wallet
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited