TransactionReceivedEvent class

Transaction received (incoming or outgoing detected)

Inheritance

Constructors

TransactionReceivedEvent({required String walletId, required String txid, required BigInt amountSatoshis, required bool isIncoming})

Properties

amountSatoshis → BigInt
final
eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isIncoming → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txid → String
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited