TransactionsResponse class

Transactions query response

Inheritance

Constructors

TransactionsResponse({required String walletId, required String queryId, required List<BitcoinTransaction> transactions})

Properties

eventTimestamp → DateTime
Timestamp of the event
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
queryId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactions → List<BitcoinTransaction>
final
walletId → String
Optional wallet ID for filtering events by wallet
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited