WalletCreatedEvent class
Wallet successfully created
- Inheritance
-
- Object
- CoordinatorEvent
- WalletCreatedEvent
Constructors
- WalletCreatedEvent({required String walletId, String? rootAddress, required bool success, String? error})
Properties
- error → String?
-
final
- eventTimestamp → DateTime
-
Timestamp of the event
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- rootAddress → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
- walletId → String
-
Optional wallet ID for filtering events by wallet
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited