AcceptChannelCommand class

Server accepts a channel request

Flow: Server → AcceptChannelCommand → ChannelAcceptedEvent → P2P → Client

Note: serverPubKeyHex, serverAddressB58, and derivationIndex must be pre-computed by WalletManager before creating this command.

Inheritance

Constructors

AcceptChannelCommand({required String channelId, required String walletId, required String clientPeerId, required String clientPubKeyHex, required String clientAddressB58, required String serverPubKeyHex, required String serverAddressB58, required int derivationIndex, required BigInt fundingAmountSats, required int lockTimeUnix, String? context, String? commandId, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

channelId String
finalinherited
clientAddressB58 String
final
clientPeerId String
final
clientPubKeyHex String
final
commandId String
Unique identifier for this command Used for deduplication and tracing
no setterinherited
commandType String
no setteroverride
context String?
final
correlationId String
finalinherited
derivationIndex int
final
fundingAmountSats BigInt
final
hashCode int
The hash code for this object.
no setterinherited
lockTimeUnix int
final
metadata Map<String, dynamic>
finalinherited
payload → dynamic
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverAddressB58 String
final
serverPubKeyHex String
final
timestamp DateTime
finalinherited
walletId String
final

Methods

getValidationErrors() List<String>
Get validation errors Override in subclasses to provide specific error messages
inherited
isValid() bool
Validate the command Override in subclasses for custom validation
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() List<int>
Serialize command to CBOR bytes
inherited
toMap() Map<String, dynamic>
Convert command to a map for serialization Override in subclasses to include command-specific data
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited