AcceptChannelMessage class

Request to accept a channel as server

Constructors

AcceptChannelMessage({required String channelId, required String walletId, required String clientPeerId, required String clientPubKeyHex, required String clientAddressB58, required BigInt fundingAmountSats, required int lockTimeUnix, String? context})

Properties

channelId → String
final
clientAddressB58 → String
final
clientPeerId → String
final
clientPubKeyHex → String
final
context → String?
final
correlationId → String
finalinherited
fundingAmountSats → BigInt
final
hashCode → int
The hash code for this object.
no setterinherited
lockTimeUnix → int
final
metadata → Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
timestamp → DateTime
finalinherited
walletId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited