AcknowledgePaymentCommand class
Server acknowledges payment with pre-computed server signature
Note: Signing is delegated to WalletManager. The server signature must be obtained before creating this command.
This command triggers:
- Validation (sequence incrementing, amounts correct)
- PaymentAcknowledgedEvent emission with fully signed TX
- Inheritance
-
- Object
- ChannelCommand
- AcknowledgePaymentCommand
Constructors
-
AcknowledgePaymentCommand({required String channelId, required BigInt amountSats, required String paymentTxHex, required String clientSignatureHex, required String serverSignatureHex, required String fullySignedPaymentTxHex, required int proposedSequence, required BigInt proposedClientBalance, required BigInt proposedServerBalance, String? commandId, DateTime? timestamp, Map<
String, dynamic> ? metadata})
Properties
- amountSats → BigInt
-
final
- channelId → String
-
finalinherited
- clientSignatureHex → String
-
final
- commandId → String
-
Unique identifier for this command
Used for deduplication and tracing
no setterinherited
- commandType → String
-
no setteroverride
- correlationId → String
-
finalinherited
- fullySignedPaymentTxHex → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
- paymentTxHex → String
-
final
- proposedClientBalance → BigInt
-
final
- proposedSequence → int
-
final
- proposedServerBalance → BigInt
-
final
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- serverSignatureHex → String
-
final
- timestamp → DateTime
-
finalinherited
Methods
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the command
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize command to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert command to a map for serialization
Override in subclasses to include command-specific data
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited