AcknowledgePaymentMessage class

Request to acknowledge a payment as server

Constructors

AcknowledgePaymentMessage({required String channelId, required String walletId, required BigInt amountSats, required String paymentTxHex, required String clientSignatureHex, required int proposedSequence, required BigInt proposedClientBalance, required BigInt proposedServerBalance})

Properties

amountSats BigInt
final
channelId String
final
clientSignatureHex String
final
correlationId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
paymentTxHex String
final
proposedClientBalance BigInt
final
proposedSequence int
final
proposedServerBalance BigInt
final
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
timestamp DateTime
finalinherited
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited