fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static AddressDiscoveredEvent fromMap(Map<String, dynamic> map) {
return AddressDiscoveredEvent(
walletId: map['walletId'] as String,
address: map['address'] as String,
derivationIndex: map['derivationIndex'] as int,
isChange: map['isChange'] as bool,
transactionCount: map['transactionCount'] as int,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null
? (map['timestamp'] is String
? DateTime.parse(map['timestamp'] as String)
: map['timestamp'] as DateTime)
: null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);
}