fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static AddressLabelUpdatedEvent fromMap(Map<String, dynamic> map) {
return AddressLabelUpdatedEvent(
walletId: map['walletId'] as String,
address: map['address'] as String,
newLabel: map['newLabel'] as String?,
oldLabel: map['oldLabel'] as String?,
eventId: map['eventId'] as String?,
timestamp: map['timestamp'] != null
? (map['timestamp'] is String
? DateTime.parse(map['timestamp'] as String)
: map['timestamp'] as DateTime)
: null,
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);
}