BuildFundingTransactionCommand class
Command to build and sign a payment channel funding transaction.
This creates a 2-of-2 multisig output funded by the client's UTXOs. The signing happens entirely within the wallet aggregate, keeping keys secure.
- Inheritance
-
- Object
- WalletCommand
- BuildFundingTransactionCommand
Constructors
-
BuildFundingTransactionCommand({required String walletId, required String correlationId, required String channelId, required String clientPubKeyHex, required String serverPubKeyHex, required int fundingAmountSats, required String changeAddressBase58, int? derivationIndex, String? commandId, DateTime? timestamp, Map<
String, dynamic> ? metadata})
Properties
- changeAddressBase58 → String
-
final
- channelId → String
-
final
- clientPubKeyHex → String
-
final
- commandId → String
-
Unique identifier for this command
Used for deduplication and tracing
no setterinherited
- commandType → String
-
Command type identifier for logging and debugging
no setteroverride
- correlationId → String
-
The correlation ID of the message.
final
- derivationIndex → int?
-
final
- fundingAmountSats → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- serverPubKeyHex → String
-
final
- timestamp → DateTime
-
finalinherited
- walletId → String
-
finalinherited
Methods
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the command
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize command to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert command to a map for serialization
Override in subclasses to include command-specific data
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited