BuildRefundTransactionMessage class

Request to build refund transaction (client side, after server accepts)

Constructors

BuildRefundTransactionMessage({required String channelId, required String walletId, required String fundingTxId, required int fundingOutputIndex, required BigInt fundingAmountSats, required String clientPubKeyHex, required String clientAddressB58, required String serverPubKeyHex, required String serverAddressB58, required int lockTimeUnix})

Properties

channelId String
final
clientAddressB58 String
final
clientPubKeyHex String
final
correlationId String
finalinherited
fundingAmountSats BigInt
final
fundingOutputIndex int
final
fundingTxId String
final
hashCode int
The hash code for this object.
no setterinherited
lockTimeUnix int
final
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverAddressB58 String
final
serverPubKeyHex String
final
timestamp DateTime
finalinherited
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited