ChannelAcceptedEvent class
Server has accepted a channel request
- Inheritance
-
- Object
- ChannelEvent
- ChannelAcceptedEvent
Constructors
-
ChannelAcceptedEvent({required String channelId, required String walletId, required String clientPeerId, required String clientPubKeyHex, required String clientAddressB58, required String serverPubKeyHex, required String serverAddressB58, required int derivationIndex, required BigInt fundingAmountSats, required int lockTimeUnix, String? context, String? eventId, DateTime? timestamp, int? version, Map<
String, dynamic> ? metadata}) -
ChannelAcceptedEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
- channelId → String
-
finalinherited
- clientAddressB58 → String
-
final
- clientPeerId → String
-
final
- clientPubKeyHex → String
-
final
- context → String?
-
final
- correlationId → String
-
The correlation ID of the message.
no setterinherited
- derivationIndex → int
-
final
- eventId → String
-
Unique identifier for this event
Used for deduplication and correlation
no setterinherited
- fundingAmountSats → BigInt
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockTimeUnix → int
-
final
-
metadata
→ Map<
String, dynamic> -
Additional metadata for the event
Can include correlation IDs, causation IDs, user context, etc.
no setterinherited
- replyTo → ActorRef?
-
The actor to reply to.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverAddressB58 → String
-
final
- serverPubKeyHex → String
-
final
- timestamp → DateTime
-
Timestamp when the event occurred
no setterinherited
- version → int
-
Version/sequence number of this event within its aggregate
Used for ordering and optimistic concurrency control
no setterinherited
- walletId → String
-
final
Methods
-
getChannelEventData(
) → Map< String, dynamic> -
Override to provide event-specific data for serialization
override
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the event
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize event to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert event to a map for serialization
Override in subclasses to include event-specific data
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited