copyWith method
Create a copy of this state with updated version and timestamp Subclasses should override to provide type-safe copying
Implementation
@override
State copyWith({int? version, DateTime? lastModified}) {
// We don't use copyWith pattern in this implementation
// State mutations happen directly in eventHandler
throw UnimplementedError('copyWith not used for ChannelState');
}