payerAnchorContext property
The context of the wallet's own anchor to pay with, as payer key B, instead of a fresh payer key: a payment made as the identity that anchor stands for (the sender of a BRC-29 payment to a BRC-100 wallet is its identity key).
Implementation
final List<int>? payerAnchorContext;