FullChannelStateResponse class
Full channel state response from aggregate (for building transactions)
Constructors
- FullChannelStateResponse({required String channelId, required String walletId, required String status, String? role, required BigInt clientBalanceSats, required BigInt serverBalanceSats, required int latestSequenceNumber, required BigInt fundingAmountSats, String? fundingTxId, String? fundingTxHex, int? fundingOutputIndex, String? clientPubKeyHex, String? serverPubKeyHex, String? clientAddressB58, String? serverAddressB58, int? derivationIndex, int? lockTimeUnix, required bool success, String? error})
Properties
- channelId → String
-
final
- clientAddressB58 → String?
-
final
- clientBalanceSats → BigInt
-
final
- clientPubKeyHex → String?
-
final
- correlationId → String
-
finalinherited
- derivationIndex → int?
-
final
- error → String?
-
final
- fundingAmountSats → BigInt
-
final
- fundingOutputIndex → int?
-
final
- fundingTxHex → String?
-
final
- fundingTxId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latestSequenceNumber → int
-
final
- lockTimeUnix → int?
-
final
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
no setter
- replyTo → ActorRef?
-
finalinherited
- role → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- serverAddressB58 → String?
-
final
- serverBalanceSats → BigInt
-
final
- serverPubKeyHex → String?
-
final
- status → String
-
final
- success → bool
-
final
- timestamp → DateTime
-
finalinherited
- walletId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited