LegacyWatchAddress class
A watch address the read model recorded before watch addresses were
journaled (an address row with purpose watch).
Constructors
- LegacyWatchAddress({required String address, required String scriptType, String? label, required DateTime registeredAt})
-
const
Properties
- address → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- registeredAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited