PaymentChannelManagerActor class

Payment Channel Manager - Orchestrates all channel operations

Constructors

PaymentChannelManagerActor({required ActorRef walletManager, required EventStore eventStore, required CryptoService cryptoService, NetworkType networkType = dartsv.NetworkType.TEST, void eventBroadcaster(ChannelEvent)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(Object error, StackTrace stackTrace) → void
Called when an error occurs.
inherited
onMessage(dynamic message) Future<void>
Called when a message is received.
postStop() → void
Called when the actor is stopped.
inherited
preStart() → void
Called when the actor is started.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited