ProvideRefundSignatureCommand class

Server provides their signature on the refund transaction

Inheritance

Constructors

ProvideRefundSignatureCommand({required String channelId, required String serverSignatureHex, String? commandId, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

channelId String
finalinherited
commandId String
Unique identifier for this command Used for deduplication and tracing
no setterinherited
commandType String
no setteroverride
correlationId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
payload → dynamic
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverSignatureHex String
final
timestamp DateTime
finalinherited

Methods

getValidationErrors() List<String>
Get validation errors Override in subclasses to provide specific error messages
inherited
isValid() bool
Validate the command Override in subclasses for custom validation
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() List<int>
Serialize command to CBOR bytes
inherited
toMap() Map<String, dynamic>
Convert command to a map for serialization Override in subclasses to include command-specific data
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited