RecordImportedTransactionCommand class

Command to record an imported transaction (from blockchain scan)

Inheritance

Constructors

RecordImportedTransactionCommand({required String walletId, required String txid, required String rawHex, required int blockHeight, required String bumpProofHex, required int totalOutputSats, required int numInputs, required int numOutputs, required int txVersion, required int txLockTime, required List<String> walletReceivingAddresses, required int walletReceivedSats, required int totalInputSats, required List<String> sendingAddresses, String? commandId, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

blockHeight int
final
bumpProofHex String
final
commandId String
Unique identifier for this command Used for deduplication and tracing
no setterinherited
commandType String
Command type identifier for logging and debugging
no setteroverride
correlationId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
numInputs int
final
numOutputs int
final
payload → dynamic
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
rawHex String
final
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
sendingAddresses List<String>
final
timestamp DateTime
finalinherited
totalInputSats int
final
totalOutputSats int
final
txid String
final
txLockTime int
final
txVersion int
final
walletId String
finalinherited
walletReceivedSats int
final
walletReceivingAddresses List<String>
final

Methods

getValidationErrors() List<String>
Get validation errors Override in subclasses to provide specific error messages
inherited
isValid() bool
Validate the command Override in subclasses for custom validation
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() List<int>
Serialize command to CBOR bytes
inherited
toMap() Map<String, dynamic>
Convert command to a map for serialization Override in subclasses to include command-specific data
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited