RecordOutgoingTransactionCommand class

Command to record an outgoing transaction (payment created by this wallet) Records transaction in PENDING state until payment is confirmed by recipient

Inheritance

Constructors

RecordOutgoingTransactionCommand({required String walletId, required String txid, required String rawHex, required int totalInputSats, required int totalOutputSats, required int fee, required int numInputs, required int numOutputs, required int txVersion, required int txLockTime, required List<String> spentUtxoKeys, required List<String> recipientAddresses, required BigInt paymentAmount, String? changeAddress, BigInt? changeAmount, String? commandId, DateTime? timestamp, Map<String, dynamic>? metadata})

Properties

changeAddress String?
final
changeAmount BigInt?
final
commandId String
Unique identifier for this command Used for deduplication and tracing
no setterinherited
commandType String
Command type identifier for logging and debugging
no setteroverride
correlationId String
finalinherited
fee int
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
numInputs int
final
numOutputs int
final
payload → dynamic
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
paymentAmount BigInt
final
rawHex String
final
recipientAddresses List<String>
final
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
spentUtxoKeys List<String>
final
timestamp DateTime
finalinherited
totalInputSats int
final
totalOutputSats int
final
txid String
final
txLockTime int
final
txVersion int
final
walletId String
finalinherited

Methods

getValidationErrors() List<String>
Get validation errors Override in subclasses to provide specific error messages
inherited
isValid() bool
Validate the command Override in subclasses for custom validation
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() List<int>
Serialize command to CBOR bytes
inherited
toMap() Map<String, dynamic>
Convert command to a map for serialization Override in subclasses to include command-specific data
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited