RecordPaymentMessage class

Request to record a payment as client

Constructors

RecordPaymentMessage({required String channelId, required String walletId, required BigInt amountSats, String? purpose, String? invoiceId})

Properties

amountSats BigInt
final
channelId String
final
correlationId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
final
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
purpose String?
final
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
timestamp DateTime
finalinherited
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited