RecordSettlementMessage class
The settlement a channel's server broadcast, handed to the client in
channel_closed (bead libspiffy-u6q6): the client checks it is its
latest payment, fully signed, records its return leg and closes the
channel. Answered with ChannelClosedResponse.
Constructors
- RecordSettlementMessage({required String channelId, required String settlementTxHex})
Properties
- channelId → String
-
final
- correlationId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
no setter
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- settlementTxHex → String
-
final
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited