refundTxHex property
Server side (libspiffy-fsy): the refund template the server signed and the funding transaction it spends. Null on the client side and in rows written before they were journaled.
Implementation
final String? refundTxHex;
Server side (libspiffy-fsy): the refund template the server signed and the funding transaction it spends. Null on the client side and in rows written before they were journaled.
final String? refundTxHex;