RefundTransactionBuiltResponse class

Response with built refund transaction

Constructors

RefundTransactionBuiltResponse({required String channelId, required String refundTxHex, required bool success, String? error})

Properties

channelId → String
final
correlationId → String
finalinherited
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
finalinherited
payload → dynamic
no setter
refundTxHex → String
final
replyTo → ActorRef?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
success → bool
final
timestamp → DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited