ReleasedDeferredInput class
A UTXO a deferred payment's failure or cancellation released, and the status it returned to.
Constructors
- ReleasedDeferredInput({required String utxoKey, required UTXOStatus restoredStatus})
-
const
- ReleasedDeferredInput.fromMap(Map map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- restoredStatus → UTXOStatus
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utxoKey → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
listFrom(
Object? value) → List< ReleasedDeferredInput>