RequestRefundSignatureCommand class
Server journals its signature on the client's refund transaction.
Note: Signing is delegated to WalletManager. The signature must be obtained before creating this command.
The aggregate accepts it only for a refund that spends exactly fundingTxId:fundingOutputIndex with the channel lockTime and a non-final input sequence and, when fundingTxHex is given, only if that output locks the agreed amount in the channel's 2-of-2 (libspiffy-fsy).
- Inheritance
-
- Object
- ChannelCommand
- RequestRefundSignatureCommand
Constructors
-
RequestRefundSignatureCommand({required String channelId, required String fundingTxId, required int fundingOutputIndex, required String refundTxHex, required int lockTimeUnix, required String serverSignatureHex, String? fundingTxHex, String? commandId, DateTime? timestamp, Map<
String, dynamic> ? metadata})
Properties
- channelId → String
-
finalinherited
- commandId → String
-
Unique identifier for this command
Used for deduplication and tracing
no setterinherited
- commandType → String
-
no setteroverride
- correlationId → String
-
finalinherited
- fundingOutputIndex → int
-
final
- fundingTxHex → String?
-
The funding transaction the refund spends, as the client sent it.
final
- fundingTxId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockTimeUnix → int
-
final
-
metadata
→ Map<
String, dynamic> -
finalinherited
- payload → dynamic
-
Override payload to return the command itself for LocalMessage compatibility
no setterinherited
-
persistableMetadata
→ Map<
String, dynamic> -
metadataas it is persisted: transientActorRefentries removed.no setterinherited - refundTxHex → String
-
final
- replyTo → ActorRef?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → ActorRef?
-
finalinherited
- serverSignatureHex → String
-
final
- timestamp → DateTime
-
finalinherited
- typeName → String
-
Stable identity of this command type in storage.
no setterinherited
Methods
-
getValidationErrors(
) → List< String> -
Get validation errors
Override in subclasses to provide specific error messages
inherited
-
isValid(
) → bool -
Validate the command
Override in subclasses for custom validation
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → List< int> -
Serialize command to CBOR bytes
inherited
-
toMap(
) → Map< String, dynamic> -
Convert command to a map for serialization.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited