SignRefundTransactionMessage class

Request to sign refund transaction (server side)

Constructors

SignRefundTransactionMessage({required String channelId, required String walletId, required String refundTxHex, required String clientPubKeyHex, required String serverPubKeyHex, required String serverAddressB58, required int derivationIndex, required BigInt fundingAmountSats, required int lockTimeUnix})

Properties

channelId String
final
clientPubKeyHex String
final
correlationId String
finalinherited
derivationIndex int
final
fundingAmountSats BigInt
final
hashCode int
The hash code for this object.
no setterinherited
lockTimeUnix int
final
metadata Map<String, dynamic>
finalinherited
payload → dynamic
no setter
refundTxHex String
final
replyTo → ActorRef?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → ActorRef?
finalinherited
serverAddressB58 String
final
serverPubKeyHex String
final
timestamp DateTime
finalinherited
walletId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited