fromMap static method
Create event from a map during deserialization This is a factory method that should be implemented by concrete event classes
Implementation
static TransactionAncestorsRecordedEvent fromMap(Map<String, dynamic> map) => TransactionAncestorsRecordedEvent(
walletId: map['walletId'] as String,
txid: map['txid'] as String,
ancestors: [
for (final a in (map['ancestors'] as List<dynamic>)) BeefAncestor.fromMap(a as Map<dynamic, dynamic>),
],
eventId: map['eventId'] as String?,
timestamp: _deferredDate(map['timestamp']),
version: map['version'] as int?,
metadata: map['metadata'] as Map<String, dynamic>?,
);