AddressEntity class

Address entity for efficient address lookup and metadata

Annotations
  • @collection

Constructors

AddressEntity()
AddressEntity.fromJson(Map<String, dynamic> json)
Deserialize from JSON for restore
factory

Properties

address String
Bitcoin address (base58) or payment destination identifier
getter/setter pair
balance String
Current balance (as string for BigInt)
getter/setter pair
createdAt DateTime
When this address was generated/discovered
getter/setter pair
derivationIndex int?
Derivation index (for quick range queries)
getter/setter pair
derivationPath String?
Derivation path (e.g., "m/44'/0'/0'/0/0")
getter/setter pair
firstUsedAt DateTime?
First time this address was used (received funds)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id ↔ Id
getter/setter pair
isChange bool
Is this a change address?
getter/setter pair
isWatched bool
Is this address currently being watched?
getter/setter pair
label String?
Address label (user-friendly name)
getter/setter pair
lastUsedAt DateTime?
Last time this address was used
getter/setter pair
purpose String
Address purpose ('receive', 'change', 'invoice', 'import')
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptType String
Script type: 'p2pkh', 'p2pk', 'p2ms', 'p2sh', 'custom', 'unknown'
getter/setter pair
usageCount int
Number of times this address has been used
getter/setter pair
walletId String
Wallet ID this address belongs to
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON for backup
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited