CdnChunkInfo class
Describes a single chunk of binary block headers on the CDN.
Constructors
- CdnChunkInfo({required String filename, required int startHeight, required int endHeight, required int headerCount, required String sha256, required int sizeBytes})
-
const
-
CdnChunkInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited