ForeignSpend class
One wallet output another transaction spends: found by
CheckOutputSpendersMessage, and recorded in the wallet by
CheckForeignSpendsCommand when the spender is proven.
Constructors
Properties
- confirmed → bool
-
The data source says the spender is in a block.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- proven → bool
-
The spender's merkle proof checked out against the local headers, and
its bytes spend utxoKey.
final
- recorded → bool
-
The spender is in the wallet's records: utxoKey is marked spent by
it, its outputs that pay the wallet's addresses are received, as
available, in the block its proof names, and it is in the wallet's
transaction history. Only a proven spender is recorded; a proven one
that is not says why in recordError.
final
- recordError → String?
-
Why a proven spender is not recorded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spenderBeefHex → String?
-
The spender with its merkle proof, as a BEEF, when proven: what the
wallet records, and what another wallet can import.
final
- spenderRawHex → String?
-
The spender's raw transaction, when proven.
final
- spentBy → String
-
The transaction the data source names as spending it.
final
- utxoKey → String
-
txid:voutof the wallet's output.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordedAs(
{required bool recorded, String? error}) → ForeignSpend - This spend with its recording outcome.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited