ReceiveTransactionMessage class
Receive transaction directly from counterparty with proofs (CORE SPV)
Constructors
Properties
- beef → BEEF
-
final
- correlationId → String
-
The correlation ID of the message.
no setter
- fromCounterparty → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceId → String?
-
final
-
metadata
→ Map<
String, dynamic> -
The metadata of the message.
no setter
- receivedAt → DateTime
-
final
- replyTo → ActorRef?
-
The actor to reply to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetWalletId → String?
-
final
- timestamp → DateTime
-
The timestamp of the message.
no setter
- transactionId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited