TransactionAddressEntity class

Junction table for transaction-address many-to-many relationship Enables efficient queries like "all transactions involving address X"

Annotations
  • @collection

Constructors

TransactionAddressEntity()
TransactionAddressEntity.fromJson(Map<String, dynamic> json)
Deserialize from JSON for restore
factory

Properties

address String
Address involved in this transaction
getter/setter pair
amount String
Amount in satoshis (as string for BigInt)
getter/setter pair
createdAt DateTime
When this junction record was created
getter/setter pair
direction String
Direction: 'input' or 'output'
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id ↔ Id
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txid String
Transaction ID
getter/setter pair
vin int?
Input index (vin) if this is an input
getter/setter pair
vout int?
Output index (vout) if this is an output
getter/setter pair
walletId String
Wallet ID (for partition isolation)
getter/setter pair
walletIdAddress String
Composite index for wallet+address queries
getter/setter pair
walletIdTxid String
Composite index for wallet+txid queries
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON for backup
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited