Type42KeyPath class final
The type-42 child of the wallet's anchor key for derivation.
Constructors
- Type42KeyPath(Type42Derivation derivation)
-
const
Properties
- derivation → Type42Derivation
-
final
- derivationIndex → int?
-
The derivation index of an HD path; null for a type-42 path, which has
none.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override