WalletBalanceConfig class
Configuration for wallet balance service
Constructors
Properties
-
confirmationTiers
→ List<
int> -
Confirmation tiers to track (e.g.,
1, 6, 100)final - defaultConfirmationLevel → int
-
Default confirmation level for "confirmed" balance
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConfirmationTier → int
-
Maximum confirmation tier to track
final
- reorgValidationDepth → int
-
Depth to revalidate during reorganizations
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited