WalletCoordinatorActor class
The canonical public interface for third-party apps using LibSpiffy.
Receives coordinator commands, delegates to internal actors, tracks correlations, and emits events on a broadcast stream.
Apps interact with LibSpiffy exclusively through this actor:
- Send commands via
coordinator.tell(CreateWalletCommand(...)) - Subscribe to events via
libspiffy.coordinatorEvents.listen(...)
Constructors
-
WalletCoordinatorActor({required ActorRef walletManager, required ActorRef invoiceCoordinator, required ActorRef paymentCoordinator, required ActorRef spvActor, required ActorRef arcActor, required ActorRef headerSyncActor, required ActorRef benfordCoordinator, required ActorRef channelManager, ActorRef? importActor, required ReadModelStorage storage, Stream<
ChannelEvent> ? channelEvents, String peerId = '', void broadcastWalletEvent(WalletEvent)?, dynamic importWalletFromXpriv({int addressGapLimit, String networkType, required String walletId, required String walletName, required String xpriv})?, dynamic importWalletFromWif({String networkType, required String walletId, required String walletName, required String wif})?, Stream<WalletEvent> ? walletEventsStream})
Properties
-
events
→ Stream<
CoordinatorEvent> -
Get the coordinator's event stream
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
Object error, StackTrace stackTrace) → void -
Called when an error occurs.
inherited
-
onMessage(
dynamic message) → Future< void> - Called when a message is received.
-
postStop(
) → void -
Called when the actor is stopped.
inherited
-
preStart(
) → FutureOr< void> -
Called when the actor is started.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited